@@ -470,10 +470,6 @@ class AuthService:
         check()
         return make_call(auth_pb2_grpc.AuthServiceStub(channel).ForgotPassword, request)
 
-    def GeneratePromoCode(self, request):
-        check()
-        return make_call(auth_pb2_grpc.AuthServiceStub(channel).GeneratePromoCode, request)
-
     def GoogleSignin(self, request):
         check()
         return make_call(auth_pb2_grpc.AuthServiceStub(channel).GoogleSignin, request)
@@ -520,12 +516,6 @@ class AuthService:
     def ForgotPasswordResponse(self, **kwargs):
         return auth_pb2.ForgotPasswordResponse(**kwargs)
 
-    def GeneratePromoCodeRequest(self, **kwargs):
-        return auth_pb2.GeneratePromoCodeRequest(**kwargs)
-
-    def GeneratePromoCodeResponse(self, **kwargs):
-        return auth_pb2.GeneratePromoCodeResponse(**kwargs)
-
     def GoogleSigninRequest(self, **kwargs):
         return auth_pb2.GoogleSigninRequest(**kwargs)
 
@@ -645,6 +635,10 @@ class AdminService:
         check()
         return make_call(admin_pb2_grpc.AdminServiceStub(channel).CreateUser, request)
 
+    def GeneratePromoCode(self, request):
+        check()
+        return make_call(admin_pb2_grpc.AdminServiceStub(channel).GeneratePromoCode, request)
+
     def GetGlobalProperties(self, request):
         check()
         return make_call(admin_pb2_grpc.AdminServiceStub(channel).GetGlobalProperties, request)
@@ -684,6 +678,12 @@ class AdminService:
     def CreateUserResponse(self, **kwargs):
         return admin_pb2.CreateUserResponse(**kwargs)
 
+    def GeneratePromoCodeRequest(self, **kwargs):
+        return admin_pb2.GeneratePromoCodeRequest(**kwargs)
+
+    def GeneratePromoCodeResponse(self, **kwargs):
+        return admin_pb2.GeneratePromoCodeResponse(**kwargs)
+
     def GetGlobalPropertiesRequest(self, **kwargs):
         return admin_pb2.GetGlobalPropertiesRequest(**kwargs)
 
